ConfigureServiceTemplate class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ConfigureServiceTemplate
Constructors
-
ConfigureServiceTemplate({Key? key, required ServiceTemplateSpec spec, required List<
Widget> actionsBuilder(BuildContext, Map<String, String> , bool validate()), Map<String, String> ? prefilledVars, List<String> routeDomains = const [], List<Widget> customActions = const [], List<Widget> header = const [], bool showActionRow = true, double desktopHorizontalPadding = 12, double desktopSectionSpacing = 10, double? desktopHeaderBottomSpacing, void onFormStateChanged(Map<String, String> vars, bool validate())?, String? meshagentMailDomain}) -
const
Properties
-
actionsBuilder
→ List<
Widget> Function(BuildContext, Map<String, String> , bool validate()) -
final
-
customActions
→ List<
Widget> -
final
- desktopHeaderBottomSpacing → double?
-
final
- desktopHorizontalPadding → double
-
final
- desktopSectionSpacing → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
→ List<
Widget> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- meshagentMailDomain → String?
-
final
-
onFormStateChanged
→ void Function(Map<
String, String> vars, bool validate())? -
final
-
prefilledVars
→ Map<
String, String> ? -
final
-
routeDomains
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showActionRow → bool
-
final
- spec → ServiceTemplateSpec
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited