MeshagentTerminalController class

Inheritance

Constructors

MeshagentTerminalController({void onOutput(String data)?, void onResize(int width, int height, int pixelWidth, int pixelHeight)?, int cols = 120, int rows = 32})

Properties

cols int
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
rawTerminal → TerminalController
no setter
rows int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCursor bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearSelection() → void
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
selectedText() String
sendInput(String data) → void
setCursorVisibleMode(bool visible) → void
toString() String
A string representation of this object.
inherited
write(String text) → void
writeBytes(Uint8List data) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited