Gauge class
(Optional) Gauge – same payload shape as Sum without monotonic flag.
Constructors
-
Gauge({required List<
NumberDataPoint> dataPoints}) -
Gauge.fromJson(Map<
String, dynamic> j) -
factory
Properties
-
dataPoints
→ List<
NumberDataPoint> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited