HistogramDataPoint class

Constructors

HistogramDataPoint({required int startTimeUnixNano, required int timeUnixNano, required int count, num? sum, num? min, num? max, List<int> bucketCounts = const [], List<num> explicitBounds = const [], List<Attribute> attributes = const []})
HistogramDataPoint.fromJson(Map<String, dynamic> j)
factory

Properties

attributes List<Attribute>
final
bucketCounts List<int>
final
count int
final
explicitBounds List<num>
final
hashCode int
The hash code for this object.
no setterinherited
max num?
final
min num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeUnixNano int
final
sum num?
final
timeUnixNano int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited