LogRecord class

Constructors

LogRecord({required int timeUnixNano, int? observedTimeUnixNano, required Severity severity, String? severityText, required dynamic body, List<Attribute> attributes = const []})
LogRecord.fromJson(Map<String, dynamic> j)
factory

Properties

attributes List<Attribute>
final
body → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
observedTimeUnixNano int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity Severity
final
severityText String?
final
timeUnixNano int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited