Metric class

Generic Metric wrapper – only one of sum, gauge etc. is populated.

Constructors

Metric({required String name, String? unit, String? description, Sum? sum, Gauge? gauge})
Metric.fromJson(Map<String, dynamic> j)
factory

Properties

description String?
final
gauge Gauge?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sum Sum?
final
unit String?
final

Methods

latestValueOf() num?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sumOfPoints() num
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited