OtlpMetricExport class
Constructors
-
OtlpMetricExport({required List<
ResourceMetrics> resourceMetrics}) -
OtlpMetricExport.fromJson(Map<
String, dynamic> j) -
factory
- OtlpMetricExport.fromJsonString(String jsonStr)
-
Convenience factory – supply either raw JSON string or already-decoded map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceMetrics
→ List<
ResourceMetrics> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allMetrics(
) → List< Metric> - Flatten everything into a single list of metrics.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited