Severity enum

───────────────────────────────────────────────────────────────────────────── LOG-SPECIFIC ENUMS & MODELS ─────────────────────────────────────────────────────────────────────────────

Inheritance
Available extensions

Values

unspecified → const Severity
trace → const Severity
trace2 → const Severity
trace3 → const Severity
trace4 → const Severity
debug → const Severity
debug2 → const Severity
debug3 → const Severity
debug4 → const Severity
info → const Severity
info2 → const Severity
info3 → const Severity
info4 → const Severity
warn → const Severity
warn2 → const Severity
warn3 → const Severity
warn4 → const Severity
error → const Severity
error2 → const Severity
error3 → const Severity
error4 → const Severity
fatal → const Severity
fatal2 → const Severity
fatal3 → const Severity
fatal4 → const Severity

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Severity>
A constant List of the values in this enum, in order of their declaration.