Span class
Constructors
Properties
-
attributes
→ List<
Attribute> -
final
- endTimeUnixNano → int
-
final
- flags → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → SpanKind
-
final
- name → String
-
final
- parentSpanId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spanId → String
-
final
- startTimeUnixNano → int
-
final
- status → Status?
-
final
- traceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited