Sum class
OTLP Sum (monotonic or not, cumulative/delta).
Constructors
-
Sum({required List<
NumberDataPoint> dataPoints, AggregationTemporality aggregationTemporality = AggregationTemporality.unspecified, bool isMonotonic = false}) -
Sum.fromJson(Map<
String, dynamic> j) -
factory
Properties
- aggregationTemporality → AggregationTemporality
-
final
-
dataPoints
→ List<
NumberDataPoint> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMonotonic → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited