LiveMetricSnapshot class
Constructors
Properties
- average → num?
-
no setter
-
bucketCounts
→ List<
int> -
final
- count → int?
-
final
-
explicitBounds
→ List<
num> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- kind → LiveMetricKind
-
final
- max → num?
-
final
- min → num?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sum → num?
-
final
- unit → String
-
final
- value → num?
-
final
Methods
-
estimateQuantile(
double quantile) → num? -
format(
{Map< String, dynamic> ? pricing}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited