NumberDataPoint class
Individual data-point for numeric metrics (sum / gauge).
Constructors
-
NumberDataPoint({required int startTimeUnixNano, required int timeUnixNano, required num value, List<
Attribute> attributes = const []}) -
NumberDataPoint.fromJson(Map<
String, dynamic> j) -
factory
Properties
-
attributes
→ List<
Attribute> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTimeUnixNano → int
-
final
- timeUnixNano → int
-
final
- value → num
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited