OtlpLogExport class
Constructors
-
OtlpLogExport({required List<
ResourceLogs> resourceLogs}) -
OtlpLogExport.fromJson(Map<
String, dynamic> j) -
factory
- OtlpLogExport.fromJsonString(String jsonStr)
-
Parse directly from a JSON string (file / network / etc.).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceLogs
→ List<
ResourceLogs> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allLogs(
) → List< LogRecord> - Flatten all nested LogRecords into a single list for convenience.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited