OtlpTraceExport class

Constructors

OtlpTraceExport({required List<ResourceSpans> resourceSpans})
OtlpTraceExport.fromJson(Map<String, dynamic> j)
factory
OtlpTraceExport.fromJsonString(String jsonStr)
Convenience factory to parse straight from a JSON string.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceSpans List<ResourceSpans>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

allSpans() List<Span>
Helper to flatten all nested spans into a single list.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited